// SPDX-FileCopyrightText: 2026 Kevin Ottens <kevin.ottens@enioka.com>
// SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL

#pragma once

#include <QBitArray>

#include <KCalendarCore/Alarm>
#include <KCalendarCore/Attachment>
#include <KCalendarCore/Attendee>
#include <KCalendarCore/CalFilter>
#include <KCalendarCore/CalFormat>
#include <KCalendarCore/CalStorage>
#include <KCalendarCore/Calendar>
#include <KCalendarCore/CalendarListModel>
#include <KCalendarCore/CalendarPlugin>
#include <KCalendarCore/CalendarPluginLoader>
#include <KCalendarCore/Conference>
#include <KCalendarCore/CustomProperties>
#include <KCalendarCore/Duration>
#include <KCalendarCore/Event>
#include <KCalendarCore/Exceptions>
#include <KCalendarCore/FileStorage>
#include <KCalendarCore/FreeBusy>
#include <KCalendarCore/FreeBusyCache>
#include <KCalendarCore/FreeBusyPeriod>
#include <KCalendarCore/ICalFormat>
#include <KCalendarCore/Incidence>
#include <KCalendarCore/IncidenceBase>
#include <KCalendarCore/Journal>
#include <KCalendarCore/MemoryCalendar>
#include <KCalendarCore/OccurrenceIterator>
#include <KCalendarCore/Period>
#include <KCalendarCore/Person>
#include <KCalendarCore/Recurrence>
#include <KCalendarCore/RecurrenceRule>
#include <KCalendarCore/ScheduleMessage>
#include <KCalendarCore/Sorting>
#include <KCalendarCore/Todo>
#include <KCalendarCore/VCalFormat>
#include <KCalendarCore/Visitor>
